==> ejc-bidprice-api-3.0.0-20230209.114903-15-sources.jar: com/ejianc/business/bidprice/material/vo/MaterialPicketageSupplierVO.java <==
package com.ejianc.business.bidprice.material.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料定标-供应商
 * 
 * @author generator
 * 
 */
@ApiModel("材料定标-供应商")
public class MaterialPicketageSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("清单id")
    private Long picketageDetailId;
    @ApiModelProperty("单价")
    private BigDecimal price;
    @ApiModelProperty("金额")
    private BigDecimal mny;
    @ApiModelProperty("应商id")
    private Long supplierId;
    @ApiModelProperty("供应商名称")
    private String supplierName;
    

    /**
     * 清单id
     */
    public Long getPicketageDetailId() {
        return picketageDetailId;
    }

    /**
     * 清单id
     */
    public void setPicketageDetailId(Long picketageDetailId) {
        this.picketageDetailId = picketageDetailId;
    }
    /**
     * 单价
     */
    public BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    /**
     * 应商id
     */
    public Long getSupplierId() {
        return supplierId;
    }

    /**
     * 应商id
     */
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    
}

==> ejc-bidprice-api-3.0.0-20241011.020225-160-sources.jar: com/ejianc/business/bidprice/material/vo/MaterialPicketageSupplierVO.java <==
package com.ejianc.business.bidprice.material.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料定标-供应商
 * 
 * @author generator
 * 
 */
@ApiModel("材料定标-供应商")
public class MaterialPicketageSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    @ApiModelProperty("定标主表id")
    private Long picketageId;
    @ApiModelProperty("清单id")
    private Long picketageDetailId;
    @ApiModelProperty("单价")
    private BigDecimal price;
    @ApiModelProperty("金额")
    private BigDecimal mny;
    @ApiModelProperty("应商id")
    private Long supplierId;
    @ApiModelProperty("供应商名称")
    private String supplierName;
    /**
     * 定标主表id
     */
    public Long getPicketageId() {
        return picketageId;
    }
    /**
     * 定标主表id
     */
    public void setPicketageId(Long picketageId) {
        this.picketageId = picketageId;
    }

    /**
     * 清单id
     */
    public Long getPicketageDetailId() {
        return picketageDetailId;
    }

    /**
     * 清单id
     */
    public void setPicketageDetailId(Long picketageDetailId) {
        this.picketageDetailId = picketageDetailId;
    }
    /**
     * 单价
     */
    public BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    /**
     * 应商id
     */
    public Long getSupplierId() {
        return supplierId;
    }

    /**
     * 应商id
     */
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    
}
